import lxml.html
from contextlib import suppress


def xpath_get(node, xpath):
    with suppress(RuntimeError):
        return lxml.html.fromstring(node).xpath(xpath)[0].text
    return ''


def xpath_filter(node, xpath):
    with suppress(RuntimeError):
        return [w.text for w in lxml.html.fromstring(node).xpath(xpath)]
    return []



import pika
import pickle


def delay_task_queue(ttl_delay, queue, channel, task):
    exchange = "exchange_delay_task"
    channel.exchange_declare(
        exchange=exchange, type="x-delayed-message",
        arguments={"x-delayed-type": "direct"}
    )
    channel.queue_bind(
        queue=queue, exchange=exchange, routing_key=queue
    )
    channel.basic_publish(
        exchange=exchange, routing_key=queue,
        body=pickle.dumps(task), properties=pika.BasicProperties(
            delivery_mode=2, headers={"x-delay": ttl_delay}
        )
    )


import setuptools

with open("README.rst", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="stock_crawler_utils",
    version="0.0.8",
    author="Evgeny Basmov",
    author_email="coykto@gmail.com",
    description="Utils for stock-crawler project",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Coykto/stock_crawler_utils",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'lxml',
        'pika',
        'psycopg2-binary',
    ],
)
